# hula-0.0.0.0

### What is hula?

Hula is a set of unconventional machine learning modules. Hula is designed to unify the desired aspects of most machine learning capabilities out there. 

Within hula are a few machine learning algorithms which I've coined as the following:

-  Deep Recursive Learning
-  Reinforcement via Similarity
-  Comprehensive Learning

Respectively, the modules are named:

- RecursiveL
- ReinforcementL
- ComprehensiveNet

I will be working on a blog to explain the workings behind each algorithm.

### Documentation

For Hula's documentation visit https://robert-bassett-coder.gitbook.io/workspace/
